@@ -3,10 +3,7 @@ import unittest
 from django import http
 from django import forms
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.auth.models import Group, Permission
-
-from django.contrib.auth import get_user_model
-User = get_user_model()
+from django.contrib.auth.models import User, Group, Permission
 
 import autocomplete_light
 
