@@ -1,8 +1,7 @@
 import unittest
 
-from django.contrib.auth import get_user_model
+from django.contrib.auth.models import User
 from django.db import models
-User = get_user_model()
 
 import autocomplete_light
 
